Package: asbio
Type: Package
Title: A Collection of Statistical Tools for Biologists
Version: 1.11
Depends: R (>= 3.5.0), tcltk
Imports: scatterplot3d, pixmap, plotrix, mvtnorm, deSolve, lattice,
        multcompView, grDevices, graphics, stats, utils, gWidgets2,
        gWidgets2tcltk
Suggests: boot, tkrplot, R.rsp
Date: 2025-1-24
SystemRequirements: BWidget
Authors@R: person(given = "Ken",
                    family = "Aho",
                    role = c("aut", "cre"),
                    email = "kenaho1@gmail.com")
Author: Ken Aho [aut, cre]
Maintainer: Ken Aho <kenaho1@gmail.com>
Description: Contains functions from: Aho, K. (2014) Foundational and Applied Statistics for Biologists using R.  CRC/Taylor and Francis, Boca Raton, FL, ISBN: 978-1-4398-7338-0.
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2025-01-14 23:02:22 UTC; ahoken
Repository: CRAN
Date/Publication: 2025-01-14 23:40:02 UTC
Built: R 4.3.3; ; 2025-01-15 01:03:25 UTC; unix
