# Export all names
exportPattern(.)

# Packages listed as Imports or Depends
importFrom(scatterplot3d, scatterplot3d)
importFrom(mvtnorm, dmvnorm, rmvnorm, qmvt) 
importFrom(lattice, wireframe)
importFrom(deSolve, rk4)
importFrom(plotrix, draw.circle, staxlab, thigmophobe)
importFrom(multcompView, multcompLetters)
importFrom(grDevices, hcl.colors, col2rgb, dev.capabilities, dev.cur, dev.flush, dev.hold, dev.list, dev.new, dev.off, dev.set, graphics.off, gray, heat.colors, rainbow, rgb)
importFrom(graphics, abline, arrows, axis, barplot, box, curve, grid, hist, identify, image, layout, legend, lines, locator, mtext, par, persp, plot.new, points, 
			polygon, rect, segments, symbols, text)
importFrom(stats, AIC, IQR, anova, chisq.test, coef,
             complete.cases, cor, cor.test, cov, dbeta, dbinom, dchisq, density, dexp, df, dgamma, dgeom, dhyper, dist, dlnorm, dlogis, dnbinom, dnorm,
             dpois, dt, dunif, dweibull, fitted, glm, integrate, ksmooth, lm, loess, lowess, mad, median, model.matrix, na.omit, nls, p.adjust, pbeta, pbinom, pchisq, 
			 pexp, pf, pgamma, pgeom, phyper, plnorm, plogis, pnbinom, pnorm, ppois, predict, pt, ptukey, punif, pweibull, qbeta, qbinom, qchisq, qf, qnorm, qqnorm, 
			 qsignrank, qt, qtukey, quantile, qweibull, rbinom, rchisq, resid, rexp, rnorm, rt, runif, sd, smooth.spline, t.test, terms, uniroot, var, xtabs)
importFrom(utils, compareVersion, head, write.table, stack, tail)
importFrom(stats, qqline)
importFrom(tkrplot, tkrplot)
import(
  gWidgets2,
  gWidgets2tcltk,
  tcltk,
  pixmap
)

# Method registration -print
S3method(print, addtest)
S3method(print, max_agree)
S3method(print, bci)
S3method(print, BDM)
S3method(print, blm)
S3method(print, bootstrap)
S3method(print, ci)
S3method(print, ciboot)
S3method(print, kback)
S3method(print, mltest)
S3method(print, oneSamp)
S3method(print, pairw)
S3method(print, prp.index)

# Method registration -plot
S3method(plot, pairw)
