\name{see.ttest.tck}
\alias{see.ttest.tck}

\title{
Visualize t-tests
}
\description{
Interactive GUI for demonstrating \emph{t}-tests
}
\usage{

see.ttest.tck()
}
\author{
Ken Aho
}
\keyword{graphs}
