\name{see.accPrec.tck}
\alias{see.accPrec.tck}

\title{
Interactive depiction of precision and accuracy
}
\description{
Slider GUI for examining the interaction of precision and accuracy.
}
\usage{

see.accPrec.tck()
}

\author{
Ken Aho
}
\keyword{graphs}


