\name{see.mnom.tck}
\alias{see.mnom.tck}

\title{
Interactive depiction of the multinomial distribution
}
\description{
tcltk GUI representation of the multinomial in a simple (binomial) context. 
}
\usage{
see.mnom.tck()
}

\author{
Ken Aho
}
\keyword{graphs}


