\name{cliff.env}
\alias{cliff.env}
\docType{data}
\title{Environmental data for the community dataset cliff.sp}
\description{
The data here are a subset of a dataset collected by Aho (2006) which describe the distribution of communities of lichens and vascular and avascular plant species on montane cliffs in Northeast Yellowstone National Park.  Of particular interest was whether substrate (limestone or andesitic conglomerate) or water supply influenced community composition.
}
\usage{data(cliff.env)}
\format{
This data frame contains the following columns:
  \describe{
    \item{\code{sub}}{
      a factor with 2 levels
      \code{"Andesite"} and \code{"Lime"} describing substrate type. 
    }
    \item{\code{water}}{
      a factor with 3 levels
      \code{"W"} 
      \code{"I"}
      \code{"D"}
      indicating wet, intermediate, or dry conditions. 
    }
  }
}
\details{
Two categorical environmental variables are described for 54 sites.  \code{sub} describes the substrate; there are two levels: \code{"Andesite"} and \code{"Lime"}.  \code{water} describes distance of samples from waterfalls which drain the cliff faces; there are three levels \code{"W"} indicating wet, \code{"I"} indicating intermediate, and \code{"D"} indicating dry.
}
\source{
Aho, K.(2006)  \emph{Alpine Ecology and Subalpine Cliff Ecology in the Northern Rocky 
Mountains}.  Doctoral dissertation, Montana State University, 458 pgs.
}
\keyword{datasets}
