\name{see.move}
\alias{see.move}
\alias{see.adddel}
\title{
Interactive visualization of least squares regression.  
}
\description{
Scatterplot points can be moved with \code{see.move}, while points can be added and deleted with \code{see.adddel}. The function \code{see.move} is an appropriation from \pkg{tcltk} demos, with a few bells and whistles added.
}
\usage{
see.move()
see.adddel()
}
\author{the R Development Core Team for \code{see.move}, Ken Aho for \code{see.adddel}. 
}
\keyword{graphs}


